@@ -3,7 +3,7 @@ import os
 import time
 from logging import Logger
 from pathlib import Path
-from typing import Any, Dict, Iterator, List, Optional, Union, cast
+from typing import Any, Dict, Iterator, List, Optional, Tuple, Union, cast
 from urllib import parse
 
 import requests
@@ -22,9 +22,11 @@ from darwin.exceptions import (
     MissingConfig,
     NameTaken,
     NotFound,
+    RequestEntitySizeExceeded,
     Unauthorized,
     ValidationError,
 )
+from darwin.item import DatasetItem
 from darwin.utils import (
     get_response_content,
     has_json_content_type,
@@ -110,7 +112,7 @@ class Client:
                     slug=dataset["slug"],
                     team=team_slug or self.default_team,
                     dataset_id=dataset["id"],
-                    item_count=dataset["num_images"] + dataset["num_videos"],
+                    item_count=dataset.get("num_images", 0) + dataset.get("num_videos", 0),
                     progress=dataset["progress"],
                     client=self,
                 )
@@ -175,7 +177,7 @@ class Client:
                     slug=dataset["slug"],
                     team=parsed_dataset_identifier.team_slug,
                     dataset_id=dataset["id"],
-                    item_count=dataset.get("num_items", dataset["num_images"] + dataset["num_videos"]),
+                    item_count=dataset.get("num_items", dataset.get("num_images", 0) + dataset.get("num_videos", 0)),
                     progress=0,
                     client=self,
                 )
@@ -216,7 +218,7 @@ class Client:
                 team=team_slug or self.default_team,
                 slug=dataset["slug"],
                 dataset_id=dataset["id"],
-                item_count=dataset.get("num_items", dataset["num_images"] + dataset["num_videos"]),
+                item_count=dataset.get("num_items", dataset.get("num_images", 0) + dataset.get("num_videos", 0)),
                 progress=0,
                 client=self,
             )
@@ -757,6 +759,27 @@ class Client:
         """
         self._put_raw(f"teams/{team_slug}/datasets/{dataset_slug}/items/reset", payload, team_slug)
 
+    def move_to_stage(self, dataset_slug: str, team_slug: str, filters: Dict[str, Any], stage_id: int) -> None:
+        """
+        Moves the given items to the specified stage
+
+        Parameters
+        ----------
+        dataset_slug: str
+            The slug of the dataset.
+        team_slug: str
+            The slug of the team.
+        filters: Dict[str, Any]
+            A filter Dictionary that defines the items to have the new, selected stage.
+        stage_id: int
+            ID of the stage to set.
+        """
+        payload: Dict[str, Any] = {
+            "filter": filters,
+            "workflow_stage_template_id": stage_id,
+        }
+        self._put_raw(f"teams/{team_slug}/datasets/{dataset_slug}/set_stage", payload, team_slug)
+
     def post_workflow_comment(
         self, workflow_id: int, text: str, x: float = 1, y: float = 1, w: float = 1, h: float = 1
     ) -> int:
@@ -797,7 +820,7 @@ class Client:
 
         return comment_id
 
-    def instantiate_item(self, item_id: int) -> int:
+    def instantiate_item(self, item_id: int, include_metadata: bool = False) -> Union[int, Tuple[int, DatasetItem]]:
         """
         Instantiates the given item with a workflow.
 
@@ -806,6 +829,9 @@ class Client:
         item_id: int
             The id of the item to be instantiated.
 
+        include_metadata: bool
+            If set to True, this method returns a tuple instead, with 2nd element being DatasetItem.
+
         Returns
         -------
         int
@@ -822,7 +848,10 @@ class Client:
         if id is None:
             raise ValueError(f"No Workflow Id found for item_id: {item_id}")
 
-        return id
+        if include_metadata:
+            return (id, DatasetItem.parse(response))
+        else:
+            return id
 
     def fetch_binary(self, url: str) -> Response:
         """
@@ -1125,6 +1154,9 @@ class Client:
         if response.status_code == 404:
             raise NotFound(url)
 
+        if response.status_code == 413:
+            raise RequestEntitySizeExceeded(url)
+
         if has_json_content_type(response):
             body = response.json()
             is_name_taken: Optional[bool] = None
