@@ -161,7 +161,11 @@ class LocalFile:
         return {"files": [{"file_name": self.data["filename"], "slot_name": "0"}], "name": self.data["filename"]}
 
     def serialize_v2(self):
-        return {"slots": [{"file_name": self.data["filename"], "slot_name": "0"}], "name": self.data["filename"]}
+        return {
+            "slots": [{"file_name": self.data["filename"], "slot_name": "0", "fps": self.data["fps"]}],
+            "name": self.data["filename"],
+            "path": self.data["path"],
+        }
 
     @property
     def full_path(self) -> str:
@@ -338,6 +342,14 @@ class UploadHandler(ABC):
                     file_complete.add(file_name)
                     progress_callback(self.pending_count, 1)
 
+        if max_workers:
+            if max_workers < 1:
+                raise ValueError("max_workers must be greater than 0")
+            elif max_workers > concurrent.futures.ThreadPoolExecutor()._max_workers:
+                raise ValueError(
+                    f"max_workers must be less than or equal to {concurrent.futures.ThreadPoolExecutor()._max_workers}"
+                )
+
         if multi_threaded and self.progress:
             with concurrent.futures.ThreadPoolExecutor(max_workers=max_workers) as executor:
                 future_to_progress = {executor.submit(f, callback) for f in self.progress}
@@ -439,7 +451,7 @@ class UploadHandlerV1(UploadHandler):
                     if upload_response.status_code != 503:
                         break
 
-                    time.sleep(2 ** retries)
+                    time.sleep(2**retries)
                     retries += 1
 
             upload_response.raise_for_status()
@@ -532,7 +544,7 @@ class UploadHandlerV2(UploadHandler):
                     if upload_response.status_code != 503:
                         break
 
-                    time.sleep(2 ** retries)
+                    time.sleep(2**retries)
                     retries += 1
 
             upload_response.raise_for_status()
