@@ -1,6 +1,20 @@
 from pathlib import Path
 
 
+class IncompatibleOptions(Exception):
+    """
+    Used when a combination of options has one or more options that are not compatible between them.
+    An option is not compatible with another if any combination from their set of possibilities
+    returns an unspecified result.
+    """
+
+
+class UnrecognizableFileEncoding(Exception):
+    """
+    Used when a we try to decode a file and all decoding algorithms fail.
+    """
+
+
 class Unauthenticated(Exception):
     """
     Used when a user tries to perform an action that requires authentication without being
@@ -8,28 +22,24 @@ class Unauthenticated(Exception):
     """
 
 
-
 class InvalidLogin(Exception):
     """
     Used when a user tries to log in with invalid credentials.
     """
 
 
-
 class InvalidTeam(Exception):
     """
     Used when a team is not found or has no valid API key.
     """
 
 
-
 class MissingConfig(Exception):
     """
     Used when the configuration file was not found.
     """
 
 
-
 class UnsupportedExportFormat(Exception):
     """
     Used when one tries to export an annotation into a format that is not supported.
@@ -84,21 +94,18 @@ class InsufficientStorage(Exception):
     """
 
 
-
 class NameTaken(Exception):
     """
     Used when one tries to create an entity and the name of that entity is already taken.
     """
 
 
-
 class ValidationError(Exception):
     """
     Used when a validation fails.
     """
 
 
-
 class Unauthorized(Exception):
     """
     Used when a user tries to perform an action without having the necessary permissions.
@@ -113,3 +120,25 @@ class OutdatedDarwinJSONFormat(Exception):
     Used when one tries to parse a video with an old darwin format that is no longer compatible.
     """
 
+
+class RequestEntitySizeExceeded(Exception):
+    """
+    Used when a request fails due to the URL being too long.
+    """
+
+
+class UnknownExportVersion(Exception):
+    """Used when dataset version is not recognized."""
+
+    def __init__(self, version: str):
+        """
+        Parameters
+        ----------
+        version: str
+            The version that is not recognized.
+        """
+        super().__init__()
+        self.version = version
+
+    def __str__(self):
+        return f"Unknown version: '{self.version}'"
