@@ -1,4 +1,3 @@
-from ast import Or
 from pathlib import Path
 from typing import (
     TYPE_CHECKING,
@@ -20,9 +19,15 @@ if TYPE_CHECKING:
 import darwin.datatypes as dt
 import deprecation
 from darwin.datatypes import PathLike
+from darwin.exceptions import IncompatibleOptions, RequestEntitySizeExceeded
 from darwin.utils import secure_continue_request
 from darwin.version import __version__
+from rich.console import Console
 from rich.progress import track
+from rich.theme import Theme
+
+# Classes missing import support on backend side
+UNSUPPORTED_CLASSES = ["string", "graph"]
 
 DEPRECATION_MESSAGE = """
 
@@ -50,6 +55,9 @@ def build_main_annotations_lookup_table(annotation_classes: List[Dict[str, Any]]
         "polygon",
         "skeleton",
         "tag",
+        "string",
+        "table",
+        "graph",
     ]
     lookup: Dict[str, Any] = {}
     for cls in annotation_classes:
@@ -112,13 +120,13 @@ def build_attribute_lookup(dataset: "RemoteDataset") -> Dict[str, Any]:
     current_version=__version__,
     details=DEPRECATION_MESSAGE,
 )
-def get_remote_files(dataset: "RemoteDataset", filenames: List[str]) -> Dict[str, int]:
-    """Fetches remote files from the datasets, in chunks of 100 filesnames at a time"""
+def get_remote_files(dataset: "RemoteDataset", filenames: List[str], chunk_size: int() = 100) -> Dict[str, int]:
+    """Fetches remote files from the datasets in chunks; by default 100 filenames at a time"""
     remote_files = {}
-    for i in range(0, len(filenames), 100):
-        chunk = filenames[i : i + 100]
+    for i in range(0, len(filenames), chunk_size):
+        chunk = filenames[i : i + chunk_size]
         for remote_file in dataset.fetch_remote_files(
-            {"types": "image,playback_video,video_frame", "filenames": ",".join(chunk)}
+            {"types": "image,playback_video,video_frame", "filenames": chunk}
         ):
             remote_files[remote_file.full_path] = remote_file.id
     return remote_files
@@ -158,6 +166,7 @@ def import_annotations(
     file_paths: List[PathLike],
     append: bool,
     class_prompt: bool = True,
+    delete_for_empty: bool = False,
 ) -> None:
     """
     Imports the given given Annotations into the given Dataset.
@@ -173,25 +182,49 @@ def import_annotations(
         A list of ``Path``'s or strings containing the Annotations we wish to import.
     append : bool
         If ``True`` appends the given annotations to the datasets. If ``False`` will override them.
+        Incompatible with ``delete-for-empty``.
     class_prompt : bool
         If ``False`` classes will be created and added to the datasets without requiring a user's prompt.
+    delete_for_empty : bool, default: False
+        If ``True`` will use empty annotation files to delete all annotations from the remote file.
+        If ``False``, empty annotation files will simply be skipped.
+        Only works for V2 datasets.
+        Incompatible with ``append``.
 
     Raises
     -------
     ValueError
+
         - If ``file_paths`` is not a list.
         - If the application is unable to fetch any remote classes.
         - If the application was unable to find/parse any annotation files.
+        - If the application was unable to fetch remote file list.
+
+    IncompatibleOptions
+
+        - If both ``append`` and ``delete_for_empty`` are specified as ``True``.
     """
+    console = Console(theme=_console_theme())
+
+    if append and delete_for_empty:
+        raise IncompatibleOptions(
+            "The options 'append' and 'delete_for_empty' cannot be used together. Use only one of them."
+        )
 
     if not isinstance(file_paths, list):
         raise ValueError(f"file_paths must be a list of 'Path' or 'str'. Current value: {file_paths}")
 
-    print("Fetching remote class list...")
+    console.print("Fetching remote class list...", style="info")
     team_classes: List[Dict[str, Any]] = dataset.fetch_remote_classes(True)
     if not team_classes:
         raise ValueError("Unable to fetch remote class list.")
 
+    if delete_for_empty and dataset.version == 1:
+        console.print(
+            f"The '--delete-for-empty' flag only works for V2 datasets. '{dataset.name}' is a V1 dataset. Ignoring flag.",
+            style="warning",
+        )
+
     classes_in_dataset: Dict[str, Any] = build_main_annotations_lookup_table(
         [cls for cls in team_classes if cls["available"]]
     )
@@ -200,7 +233,7 @@ def import_annotations(
     )
     attributes = build_attribute_lookup(dataset)
 
-    print("Retrieving local annotations ...")
+    console.print("Retrieving local annotations ...", style="info")
     local_files = []
     local_files_missing_remotely = []
     maybe_parsed_files: Optional[Iterable[dt.AnnotationFile]] = find_and_parse(importer, file_paths)
@@ -210,21 +243,34 @@ def import_annotations(
     parsed_files = list(maybe_parsed_files)
     filenames: List[str] = [parsed_file.filename for parsed_file in parsed_files]
 
-    print("Fetching remote file list...")
+    console.print("Fetching remote file list...", style="info")
     # This call will only filter by filename; so can return a superset of matched files across different paths
     # There is logic in this function to then include paths to narrow down to the single correct matching file
-    remote_files = get_remote_files(dataset, filenames)
+    remote_files = []
+
+    # Try to fetch files in large chunks; in case the filenames are too large and exceed the url size
+    # retry in smaller chunks
+    chunk_size = 100
+    while chunk_size > 0:
+        try:
+            remote_files = get_remote_files(dataset, filenames, chunk_size)
+            break
+        except RequestEntitySizeExceeded as e:
+            chunk_size -= 8
+            if chunk_size <= 0:
+                raise ValueError("Unable to fetch remote file list.")
+
     for parsed_file in parsed_files:
         if parsed_file.full_path not in remote_files:
             local_files_missing_remotely.append(parsed_file)
         else:
             local_files.append(parsed_file)
 
-    print(f"{len(local_files) + len(local_files_missing_remotely)} annotation file(s) found.")
+    console.print(f"{len(local_files) + len(local_files_missing_remotely)} annotation file(s) found.", style="info")
     if local_files_missing_remotely:
-        print(f"{len(local_files_missing_remotely)} file(s) are missing from the dataset")
+        console.print(f"{len(local_files_missing_remotely)} file(s) are missing from the dataset", style="warning")
         for local_file in local_files_missing_remotely:
-            print(f"\t{local_file.path}: '{local_file.full_path}'")
+            console.print(f"\t{local_file.path}: '{local_file.full_path}'", style="warning")
 
         if class_prompt and not secure_continue_request():
             return
@@ -235,22 +281,26 @@ def import_annotations(
         classes_in_team,
     )
 
-    print(f"{len(local_classes_not_in_team)} classes needs to be created.")
-    print(f"{len(local_classes_not_in_dataset)} classes needs to be added to {dataset.identifier}")
+    console.print(f"{len(local_classes_not_in_team)} classes needs to be created.", style="info")
+    console.print(
+        f"{len(local_classes_not_in_dataset)} classes needs to be added to {dataset.identifier}", style="info"
+    )
 
     missing_skeletons: List[dt.AnnotationClass] = list(filter(_is_skeleton_class, local_classes_not_in_team))
     missing_skeleton_names: str = ", ".join(map(_get_skeleton_name, missing_skeletons))
     if missing_skeletons:
-        print(
-            f"Found missing skeleton classes: {missing_skeleton_names}. Missing Skeleton classes cannot be created. Exiting now."
+        console.print(
+            f"Found missing skeleton classes: {missing_skeleton_names}. Missing Skeleton classes cannot be created. Exiting now.",
+            style="error",
         )
         return
 
     if local_classes_not_in_team:
-        print("About to create the following classes")
+        console.print("About to create the following classes", style="info")
         for missing_class in local_classes_not_in_team:
-            print(
-                f"\t{missing_class.name}, type: {missing_class.annotation_internal_type or missing_class.annotation_type}"
+            console.print(
+                f"\t{missing_class.name}, type: {missing_class.annotation_internal_type or missing_class.annotation_type}",
+                style="info",
             )
         if class_prompt and not secure_continue_request():
             return
@@ -259,7 +309,7 @@ def import_annotations(
                 missing_class.name, missing_class.annotation_internal_type or missing_class.annotation_type
             )
     if local_classes_not_in_dataset:
-        print(f"About to add the following classes to {dataset.identifier}")
+        console.print(f"About to add the following classes to {dataset.identifier}", style="info")
         for cls in local_classes_not_in_dataset:
             dataset.add_annotation_class(cls)
 
@@ -273,6 +323,19 @@ def import_annotations(
     else:
         remote_classes = build_main_annotations_lookup_table(team_classes)
 
+    if dataset.version == 1:
+        console.print("Importing annotations...\nEmpty annotations will be skipped.", style="info")
+    elif dataset.version == 2 and delete_for_empty:
+        console.print(
+            "Importing annotations...\nEmpty annotation file(s) will clear all existing annotations in matching remote files.",
+            style="info",
+        )
+    else:
+        console.print(
+            "Importing annotations...\nEmpty annotations will be skipped, if you want to delete annotations rerun with '--delete-for-empty'.",
+            style="info",
+        )
+
     # Need to re parse the files since we didn't save the annotations in memory
     for local_path in set(local_file.path for local_file in local_files):
 
@@ -287,10 +350,45 @@ def import_annotations(
         # remove files missing on the server
         missing_files = [missing_file.full_path for missing_file in local_files_missing_remotely]
         parsed_files = [parsed_file for parsed_file in parsed_files if parsed_file.full_path not in missing_files]
-        for parsed_file in track(parsed_files):
-            image_id = remote_files[parsed_file.full_path]
-            _import_annotations(
-                dataset.client, image_id, remote_classes, attributes, parsed_file.annotations, dataset, append
+
+        files_to_not_track = [
+            file_to_track
+            for file_to_track in parsed_files
+            if not file_to_track.annotations and (not delete_for_empty or dataset.version == 1)
+        ]
+
+        for file in files_to_not_track:
+            console.print(f"{file.filename} has no annotations. Skipping upload...", style="warning")
+
+        files_to_track = [file for file in parsed_files if file not in files_to_not_track]
+        if files_to_track:
+            _warn_unsupported_annotations(files_to_track)
+            for parsed_file in track(files_to_track):
+                image_id = remote_files[parsed_file.full_path]
+                _import_annotations(
+                    dataset.client,
+                    image_id,
+                    remote_classes,
+                    attributes,
+                    parsed_file.annotations,
+                    dataset,
+                    append,
+                    delete_for_empty,
+                )
+
+
+def _warn_unsupported_annotations(parsed_files):
+    console = Console(theme=_console_theme())
+    for parsed_file in parsed_files:
+        skipped_annotations = []
+        for annotation in parsed_file.annotations:
+            if annotation.annotation_class.annotation_type in UNSUPPORTED_CLASSES:
+                skipped_annotations.append(annotation)
+        if len(skipped_annotations) > 0:
+            types = set(map(lambda c: c.annotation_class.annotation_type, skipped_annotations))
+            console.print(
+                f"Import of annotation class types '{', '.join(types)}' is not yet supported. Skipping {len(skipped_annotations)} annotations from '{parsed_file.full_path}'.\n",
+                style="warning",
             )
 
 
@@ -340,6 +438,7 @@ def _import_annotations(
     annotations: List[dt.Annotation],
     dataset: "RemoteDataset",
     append: bool,
+    delete_for_empty: bool,
 ):
     serialized_annotations = []
     for annotation in annotations:
@@ -377,5 +476,13 @@ def _import_annotations(
     payload: Dict[str, Any] = {"annotations": serialized_annotations}
     if append:
         payload["overwrite"] = "false"
+    else:
+        payload["overwrite"] = "true"
 
     dataset.import_annotation(id, payload=payload)
+
+
+def _console_theme() -> Theme:
+    return Theme(
+        {"success": "bold green", "warning": "bold yellow", "error": "bold red", "info": "bold deep_sky_blue1"}
+    )
