@@ -13,7 +13,7 @@ class Options(object):
     def __init__(self):
 
         self.parser: ArgumentParser = ArgumentParser(
-            description="Commandline tool to create/upload/download datasets on darwin."
+            description="Command line tool to create/upload/download datasets on darwin."
         )
 
         subparsers = self.parser.add_subparsers(dest="command")
@@ -135,9 +135,17 @@ class Options(object):
             "--include-url-token",
             default=False,
             action="store_true",
-            help="Each annotation file includes a url with an access token."
+            help="Each annotation file includes a url with an access token. "
             "Warning, anyone with the url can access the images, even without being a team member.",
         )
+        parser_export.add_argument(
+            "--version",
+            default=None,
+            type=str,
+            choices=["1.0", "2.0"],
+            help="When used for V2 dataset, allows to force generation of either Darwin JSON 1.0 (Legacy) or newer 2.0. "
+            "Omit this option to get your team's default.",
+        )
 
         # Releases
         parser_dataset_version = dataset_action.add_parser("releases", help="Available version of a dataset.")
@@ -153,6 +161,11 @@ class Options(object):
         parser_pull.add_argument(
             "--video-frames", action="store_true", help="Pulls video frame images instead of video files."
         )
+        parser_pull.add_argument(
+            "--force-slots",
+            action="store_true",
+            help="Forces pull of all slots of items into deeper file structure ({prefix}/{item_name}/{slot_name}/{file_name}). If your dataset includes items with multiple slots, or multiple source files per slot, this option becomes implicitly enabled.",
+        )
 
         # Import
         parser_import = dataset_action.add_parser("import", help="Import data to an existing (remote) dataset.")
@@ -173,6 +186,11 @@ class Options(object):
         parser_import.add_argument(
             "--yes", action="store_true", help="Skips prompts for creating and adding classes to dataset."
         )
+        parser_import.add_argument(
+            "--delete-for-empty",
+            action="store_true",
+            help="Empty annotations will delete annotations from remote files.",
+        )
 
         # Convert
         parser_convert = dataset_action.add_parser("convert", help="Converts darwin json to other annotation formats.")
